@@ -32,11 +32,7 @@ def encrypt(key, iv, plaintext):
 
 
 def decrypt(key, iv, ciphertext):
-    plaintext = aes_decrypt(key, iv, ciphertext).decode('utf-8')
-    if sys.version_info < (3, 0):
-        return unicode(plaintext)
-    else:
-        return plaintext
+    return aes_decrypt(key, iv, ciphertext).decode('utf-8')
 
 
 class NoValidSessions(Exception):
